
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "fpi-device.h" */

GType fpi_device_udev_subtype_flags_get_type (void);
#define FPI_TYPE_DEVICE_UDEV_SUBTYPE_FLAGS (fpi_device_udev_subtype_flags_get_type())

GType fpi_device_action_get_type (void);
#define FPI_TYPE_DEVICE_ACTION (fpi_device_action_get_type())

/* enumerations from "fpi-image-device.h" */

GType fpi_image_device_state_get_type (void);
#define FPI_TYPE_IMAGE_DEVICE_STATE (fpi_image_device_state_get_type())

/* enumerations from "fpi-image.h" */

GType fpi_image_flags_get_type (void);
#define FPI_TYPE_IMAGE_FLAGS (fpi_image_flags_get_type())

/* enumerations from "fpi-print.h" */

GType fpi_print_type_get_type (void);
#define FPI_TYPE_PRINT_TYPE (fpi_print_type_get_type())

GType fpi_match_result_get_type (void);
#define FPI_TYPE_MATCH_RESULT (fpi_match_result_get_type())

/* enumerations from "fpi-usb-transfer.h" */

GType fpi_transfer_type_get_type (void);
#define FPI_TYPE_TRANSFER_TYPE (fpi_transfer_type_get_type())

G_END_DECLS

/* Generated data ends here */

