
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "fp-enums.h"
#include "fp-context.h"
#include "fp-device.h"
#include "fp-image-device.h"
#include "fp-image.h"
#include "fp-print.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "fp-device.h" */

GType
fp_device_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (FP_DEVICE_TYPE_VIRTUAL), "FP_DEVICE_TYPE_VIRTUAL", "virtual" },
        { C_ENUM (FP_DEVICE_TYPE_UDEV), "FP_DEVICE_TYPE_UDEV", "udev" },
        { C_ENUM (FP_DEVICE_TYPE_USB), "FP_DEVICE_TYPE_USB", "usb" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("FpDeviceType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
fp_device_feature_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (FP_DEVICE_FEATURE_NONE), "FP_DEVICE_FEATURE_NONE", "none" },
        { C_FLAGS (FP_DEVICE_FEATURE_CAPTURE), "FP_DEVICE_FEATURE_CAPTURE", "capture" },
        { C_FLAGS (FP_DEVICE_FEATURE_IDENTIFY), "FP_DEVICE_FEATURE_IDENTIFY", "identify" },
        { C_FLAGS (FP_DEVICE_FEATURE_VERIFY), "FP_DEVICE_FEATURE_VERIFY", "verify" },
        { C_FLAGS (FP_DEVICE_FEATURE_STORAGE), "FP_DEVICE_FEATURE_STORAGE", "storage" },
        { C_FLAGS (FP_DEVICE_FEATURE_STORAGE_LIST), "FP_DEVICE_FEATURE_STORAGE_LIST", "storage-list" },
        { C_FLAGS (FP_DEVICE_FEATURE_STORAGE_DELETE), "FP_DEVICE_FEATURE_STORAGE_DELETE", "storage-delete" },
        { C_FLAGS (FP_DEVICE_FEATURE_STORAGE_CLEAR), "FP_DEVICE_FEATURE_STORAGE_CLEAR", "storage-clear" },
        { C_FLAGS (FP_DEVICE_FEATURE_DUPLICATES_CHECK), "FP_DEVICE_FEATURE_DUPLICATES_CHECK", "duplicates-check" },
        { C_FLAGS (FP_DEVICE_FEATURE_ALWAYS_ON), "FP_DEVICE_FEATURE_ALWAYS_ON", "always-on" },
        { C_FLAGS (FP_DEVICE_FEATURE_UPDATE_PRINT), "FP_DEVICE_FEATURE_UPDATE_PRINT", "update-print" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("FpDeviceFeature"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
fp_scan_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (FP_SCAN_TYPE_SWIPE), "FP_SCAN_TYPE_SWIPE", "swipe" },
        { C_ENUM (FP_SCAN_TYPE_PRESS), "FP_SCAN_TYPE_PRESS", "press" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("FpScanType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
fp_temperature_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (FP_TEMPERATURE_COLD), "FP_TEMPERATURE_COLD", "cold" },
        { C_ENUM (FP_TEMPERATURE_WARM), "FP_TEMPERATURE_WARM", "warm" },
        { C_ENUM (FP_TEMPERATURE_HOT), "FP_TEMPERATURE_HOT", "hot" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("FpTemperature"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
fp_device_retry_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (FP_DEVICE_RETRY_GENERAL), "FP_DEVICE_RETRY_GENERAL", "general" },
        { C_ENUM (FP_DEVICE_RETRY_TOO_SHORT), "FP_DEVICE_RETRY_TOO_SHORT", "too-short" },
        { C_ENUM (FP_DEVICE_RETRY_CENTER_FINGER), "FP_DEVICE_RETRY_CENTER_FINGER", "center-finger" },
        { C_ENUM (FP_DEVICE_RETRY_REMOVE_FINGER), "FP_DEVICE_RETRY_REMOVE_FINGER", "remove-finger" },
        { C_ENUM (FP_DEVICE_RETRY_TOO_FAST), "FP_DEVICE_RETRY_TOO_FAST", "too-fast" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("FpDeviceRetry"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
fp_device_error_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (FP_DEVICE_ERROR_GENERAL), "FP_DEVICE_ERROR_GENERAL", "general" },
        { C_ENUM (FP_DEVICE_ERROR_NOT_SUPPORTED), "FP_DEVICE_ERROR_NOT_SUPPORTED", "not-supported" },
        { C_ENUM (FP_DEVICE_ERROR_NOT_OPEN), "FP_DEVICE_ERROR_NOT_OPEN", "not-open" },
        { C_ENUM (FP_DEVICE_ERROR_ALREADY_OPEN), "FP_DEVICE_ERROR_ALREADY_OPEN", "already-open" },
        { C_ENUM (FP_DEVICE_ERROR_BUSY), "FP_DEVICE_ERROR_BUSY", "busy" },
        { C_ENUM (FP_DEVICE_ERROR_PROTO), "FP_DEVICE_ERROR_PROTO", "proto" },
        { C_ENUM (FP_DEVICE_ERROR_DATA_INVALID), "FP_DEVICE_ERROR_DATA_INVALID", "data-invalid" },
        { C_ENUM (FP_DEVICE_ERROR_DATA_NOT_FOUND), "FP_DEVICE_ERROR_DATA_NOT_FOUND", "data-not-found" },
        { C_ENUM (FP_DEVICE_ERROR_DATA_FULL), "FP_DEVICE_ERROR_DATA_FULL", "data-full" },
        { C_ENUM (FP_DEVICE_ERROR_DATA_DUPLICATE), "FP_DEVICE_ERROR_DATA_DUPLICATE", "data-duplicate" },
        { C_ENUM (FP_DEVICE_ERROR_REMOVED), "FP_DEVICE_ERROR_REMOVED", "removed" },
        { C_ENUM (FP_DEVICE_ERROR_TOO_HOT), "FP_DEVICE_ERROR_TOO_HOT", "too-hot" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("FpDeviceError"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "fp-print.h" */

GType
fp_finger_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (FP_FINGER_UNKNOWN), "FP_FINGER_UNKNOWN", "unknown" },
        { C_ENUM (FP_FINGER_LEFT_THUMB), "FP_FINGER_LEFT_THUMB", "left-thumb" },
        { C_ENUM (FP_FINGER_LEFT_INDEX), "FP_FINGER_LEFT_INDEX", "left-index" },
        { C_ENUM (FP_FINGER_LEFT_MIDDLE), "FP_FINGER_LEFT_MIDDLE", "left-middle" },
        { C_ENUM (FP_FINGER_LEFT_RING), "FP_FINGER_LEFT_RING", "left-ring" },
        { C_ENUM (FP_FINGER_LEFT_LITTLE), "FP_FINGER_LEFT_LITTLE", "left-little" },
        { C_ENUM (FP_FINGER_RIGHT_THUMB), "FP_FINGER_RIGHT_THUMB", "right-thumb" },
        { C_ENUM (FP_FINGER_RIGHT_INDEX), "FP_FINGER_RIGHT_INDEX", "right-index" },
        { C_ENUM (FP_FINGER_RIGHT_MIDDLE), "FP_FINGER_RIGHT_MIDDLE", "right-middle" },
        { C_ENUM (FP_FINGER_RIGHT_RING), "FP_FINGER_RIGHT_RING", "right-ring" },
        { C_ENUM (FP_FINGER_RIGHT_LITTLE), "FP_FINGER_RIGHT_LITTLE", "right-little" },
        { C_ENUM (FP_FINGER_FIRST), "FP_FINGER_FIRST", "first" },
        { C_ENUM (FP_FINGER_LAST), "FP_FINGER_LAST", "last" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("FpFinger"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
fp_finger_status_flags_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (FP_FINGER_STATUS_NONE), "FP_FINGER_STATUS_NONE", "none" },
        { C_FLAGS (FP_FINGER_STATUS_NEEDED), "FP_FINGER_STATUS_NEEDED", "needed" },
        { C_FLAGS (FP_FINGER_STATUS_PRESENT), "FP_FINGER_STATUS_PRESENT", "present" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("FpFingerStatusFlags"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

